==> ovirt-engine-3.4.1.tar.gz: packaging/setup/plugins/ovirt-engine-setup/ovirt-engine/config/macrange.py <==
#
# ovirt-engine-setup -- ovirt engine setup
# Copyright (C) 2013 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


"""macrange plugin."""


import random
import gettext
_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-setup')


from otopi import util
from otopi import plugin


from ovirt_engine_setup import constants as osetupcons


@util.export
class Plugin(plugin.PluginBase):
    """macrange plugin."""

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_INIT,
    )
    def _init(self):
        self.environment.setdefault(
            osetupcons.ConfigEnv.MAC_RANGE_POOL,
            '{newbase}:00-{newbase}:ff'.format(
                newbase='{base}:{part1:x}:{part2:x}'.format(
                    base=osetupcons.Const.MAC_RANGE_BASE,
                    part1=int(random.randrange(255)),
                    part2=int(random.randrange(255)),
                ),
            ),
        )

    @plugin.event(
        stage=plugin.Stages.STAGE_MISC,
        after=(
            osetupcons.Stages.DB_CONNECTION_AVAILABLE,
        ),
        condition=lambda self: self.environment[
            osetupcons.DBEnv.NEW_DATABASE
        ]
    )
    def _misc(self):
        self.environment[osetupcons.DBEnv.STATEMENT].updateVdcOptions(
            options=(
                {
                    'name': 'MacPoolRanges',
                    'value': self.environment[
                        osetupcons.ConfigEnv.MAC_RANGE_POOL
                    ],
                },
            ),
        )


# vim: expandtab tabstop=4 shiftwidth=4

==> ovirt-engine-3.5.2.1.tar.gz: packaging/setup/plugins/ovirt-engine-setup/ovirt-engine/config/macrange.py <==
#
# ovirt-engine-setup -- ovirt engine setup
# Copyright (C) 2013 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


"""macrange plugin."""


import random
import gettext
_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-setup')


from otopi import util
from otopi import plugin


from ovirt_engine_setup.engine import vdcoption
from ovirt_engine_setup.engine import constants as oenginecons
from ovirt_engine_setup.engine_common \
    import constants as oengcommcons


@util.export
class Plugin(plugin.PluginBase):
    """macrange plugin."""

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)

    @plugin.event(
        stage=plugin.Stages.STAGE_INIT,
    )
    def _init(self):
        self.environment.setdefault(
            oenginecons.ConfigEnv.MAC_RANGE_POOL,
            '{newbase}:00-{newbase}:ff'.format(
                newbase='{base}:{part1:x}:{part2:x}'.format(
                    base=oenginecons.Const.MAC_RANGE_BASE,
                    part1=int(random.randrange(255)),
                    part2=int(random.randrange(255)),
                ),
            ),
        )

    @plugin.event(
        stage=plugin.Stages.STAGE_MISC,
        after=(
            oengcommcons.Stages.DB_CONNECTION_AVAILABLE,
        ),
        condition=lambda self: (
            self.environment[oenginecons.CoreEnv.ENABLE] and
            self.environment[oenginecons.EngineDBEnv.NEW_DATABASE]
        ),
    )
    def _misc(self):
        vdcoption.VdcOption(
            statement=self.environment[
                oenginecons.EngineDBEnv.STATEMENT
            ]
        ).updateVdcOptions(
            options=(
                {
                    'name': 'MacPoolRanges',
                    'value': self.environment[
                        oenginecons.ConfigEnv.MAC_RANGE_POOL
                    ],
                },
            ),
        )


# vim: expandtab tabstop=4 shiftwidth=4
